<?php
/**
 * @copyright (c) 2020 www.iyuu.cn
 * @file ICrypt.php
 * @brief 加密解密
 * @author david
 * @date 2020年7月16日
 */
class ICrypt
{
    /**
     * @brief  MD5加密方法
     * @param  string $string  字符串
     * @return string $string  加密后的字符串
     */
    public static function md5($string)
    {
        return md5($string);
    }

    /**
     * @brief  SHA1加密方法
     * @param  string $string  字符串
     * @return string $string  加密后的字符串
     */
    public static function sha1($string)
    {
        return sha1($string);
    }

    /**
     * @brief base64url加密方法
     * @param  String $str 字符串
     * @return String $str 加密后字符串
     */
    public static function base64url_encode($str)
    {
        return rtrim(strtr(base64_encode($str), '+/', '-_'), '=');
    }

    /**
     * @brief  base64url解密方法
     * @param  String $str  字符串
     * @return String $str  解密后的字符串
     */
    public static function base64url_decode($str)
    {
        return base64_decode(str_pad(strtr($str, '-_', '+/'), strlen($str) % 4, '=', STR_PAD_RIGHT));
    }

    /**
     * @brief 动态加密函数
     * @param  String  $string 字符串
     * @param  Array   $config 加密参数
     * @return String   加密后的字符串
     */
    public static function encode($string, $config = array())
    {
        return self::base64url_encode(openssl_encrypt($string, $config['method'], $config['key'], OPENSSL_RAW_DATA, $config['iv']));
    }
    
    /**
     * @brief 动态解密函数
     * @param  String $string 字符串
     * @param  Array  $config 解密参数
     * @return String   解密后的字符串
     */
    public static function decode($string, $config = array())
    {
        $string = openssl_decrypt(self::base64url_decode($string), $config['method'], $config['key'], OPENSSL_RAW_DATA, $config['iv']);
        return rtrim(rtrim($string, chr(0)), chr(7));
    }
}
